@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -139,15 +139,16 @@ public class Launcher {
         while (tokenizer.hasMoreElements()) {
             final String elementName = tokenizer.nextToken();
             final File element = new File(elementName);
-            if (elementName.indexOf('%') != -1 && !element.exists()) {
+            if (elementName.contains("%") && !element.exists()) {
                 continue;
             }
             if (getJars && element.isDirectory()) {
                 // add any jars in the directory
-                final URL[] dirURLs = Locator.getLocationURLs(element);
-                for (int j = 0; j < dirURLs.length; ++j) {
-                    if (launchDiag) { System.out.println("adding library JAR: " + dirURLs[j]);}
-                    libPathURLs.add(dirURLs[j]);
+                for (URL dirURL : Locator.getLocationURLs(element)) {
+                    if (launchDiag) {
+                        System.out.println("adding library JAR: " + dirURL);
+                    }
+                    libPathURLs.add(dirURL);
                 }
             }
 
@@ -265,9 +266,9 @@ public class Launcher {
             baseClassPath.setLength(baseClassPath.length() - 1);
         }
 
-        for (int i = 0; i < jars.length; ++i) {
+        for (URL jar : jars) {
             baseClassPath.append(File.pathSeparatorChar);
-            baseClassPath.append(Locator.fromURI(jars[i].toString()));
+            baseClassPath.append(Locator.fromURI(jar.toString()));
         }
 
         setProperty(JAVA_CLASS_PATH, baseClassPath.toString());
@@ -279,7 +280,7 @@ public class Launcher {
         Throwable thrown = null;
         try {
             mainClass = loader.loadClass(mainClassname).asSubclass(AntMain.class);
-            final AntMain main = mainClass.newInstance();
+            final AntMain main = mainClass.getDeclaredConstructor().newInstance();
             main.startAnt(newArgs, null, null);
         } catch (final InstantiationException ex) {
             System.err.println(
@@ -343,7 +344,7 @@ public class Launcher {
         if (antLibDirProperty != null) {
             antLibDir = new File(antLibDirProperty);
         }
-        if ((antLibDir == null) || !antLibDir.exists()) {
+        if (antLibDir == null || !antLibDir.exists()) {
             antLibDir = antLauncherDir;
             setProperty(ANTLIBDIR_PROPERTY, antLibDir.getAbsolutePath());
         }
