@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,10 +17,14 @@
  */
 package org.apache.tools.ant.property;
 
+import java.util.Collections;
 import java.util.Deque;
+import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.stream.Collector;
 
 import org.apache.tools.ant.PropertyHelper;
 
@@ -57,7 +61,7 @@ public class LocalPropertyStack {
      */
     public void enterScope() {
         synchronized (LOCK) {
-            stack.addFirst(new ConcurrentHashMap<String, Object>());
+            stack.addFirst(new ConcurrentHashMap<>());
         }
     }
 
@@ -148,6 +152,20 @@ public class LocalPropertyStack {
         return true;
     }
 
+    /**
+     * Returns the names of all known local properties.
+     * @since 1.10.9
+     * @return the names of all known local properties.
+     */
+    public Set<String> getPropertyNames() {
+        final Set<String> names = stack.stream().map(Map::keySet)
+            .collect(Collector.of(() -> new HashSet<String>(),
+                (ns, ks) -> ns.addAll(ks),
+                (ns1, ns2) -> { ns1.addAll(ns2); return ns1; },
+                Collector.Characteristics.UNORDERED, Collector.Characteristics.IDENTITY_FINISH));
+        return Collections.unmodifiableSet(names);
+    }
+
     private Map<String, Object> getMapForProperty(String property) {
         synchronized (LOCK) {
             for (Map<String, Object> map : stack) {
