@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,7 +19,6 @@ package org.apache.tools.ant.taskdefs;
 
 import java.io.BufferedReader;
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.FileReader;
 import java.io.IOException;
 import java.io.InputStream;
@@ -27,6 +26,7 @@ import java.io.InputStreamReader;
 import java.io.Reader;
 import java.io.StringReader;
 import java.io.Writer;
+import java.nio.file.Files;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Iterator;
@@ -57,7 +57,6 @@ import org.apache.tools.ant.util.ConcatResourceInputStream;
 import org.apache.tools.ant.util.FileUtils;
 import org.apache.tools.ant.util.ReaderInputStream;
 import org.apache.tools.ant.util.ResourceUtils;
-import org.apache.tools.ant.util.StringUtils;
 
 /**
  * This class contains the 'concat' task, used to concatenate a series
@@ -130,7 +129,7 @@ public class Concat extends Task implements ResourceCollection {
         public void setFile(File file) throws BuildException {
             // non-existing files are not allowed
             if (!file.exists()) {
-                throw new BuildException("File " + file + " does not exist.");
+                throw new BuildException("File %s does not exist.", file);
             }
 
             BufferedReader reader = null;
@@ -139,7 +138,7 @@ public class Concat extends Task implements ResourceCollection {
                     reader = new BufferedReader(new FileReader(file));
                 } else {
                     reader = new BufferedReader(
-                        new InputStreamReader(new FileInputStream(file),
+                        new InputStreamReader(Files.newInputStream(file.toPath()),
                                               this.encoding));
                 }
                 value = FileUtils.safeReadFully(reader);
@@ -181,16 +180,13 @@ public class Concat extends Task implements ResourceCollection {
             if (value == null) {
                 value = "";
             }
-            if (value.trim().length() == 0) {
+            if (value.trim().isEmpty()) {
                 value = "";
             }
             if (trimLeading) {
-                char[] current = value.toCharArray();
-                StringBuffer b = new StringBuffer(current.length);
+                StringBuilder b = new StringBuilder();
                 boolean startOfLine = true;
-                int pos = 0;
-                while (pos < current.length) {
-                    char ch = current[pos++];
+                for (final char ch : value.toCharArray()) {
                     if (startOfLine) {
                         if (ch == ' ' || ch == '\t') {
                             continue;
@@ -217,7 +213,7 @@ public class Concat extends Task implements ResourceCollection {
 
     /**
      * This class reads from each of the source files in turn.
-     * The concatentated result can then be filtered as
+     * The concatenated result can then be filtered as
      * a single stream.
      */
     private final class MultiReader<S> extends Reader {
@@ -253,6 +249,7 @@ public class Concat extends Task implements ResourceCollection {
          * @exception IOException - possibly thrown by the read for a reader
          *            object.
          */
+        @Override
         public int read() throws IOException {
             if (needAddSeparator) {
                 if (lastPos >= eolString.length()) {
@@ -287,6 +284,7 @@ public class Concat extends Task implements ResourceCollection {
          * @exception IOException - possibly thrown by the reads to the
          *            reader objects.
          */
+        @Override
         public int read(char[] cbuf, int off, int len)
             throws IOException {
 
@@ -334,14 +332,14 @@ public class Concat extends Task implements ResourceCollection {
             }
             if (amountRead == 0) {
                 return -1;
-            } else {
-                return amountRead;
             }
+            return amountRead;
         }
 
         /**
          * Close the current reader
          */
+        @Override
         public void close() throws IOException {
             if (reader != null) {
                 reader.close();
@@ -353,15 +351,13 @@ public class Concat extends Task implements ResourceCollection {
          * add a character to the lastchars buffer
          */
         private void addLastChar(char ch) {
-            for (int i = lastChars.length - 2; i >= 0; --i) {
-                lastChars[i] = lastChars[i + 1];
-            }
+            System.arraycopy(lastChars, 1, lastChars, 0, lastChars.length - 2 + 1);
             lastChars[lastChars.length - 1] = ch;
         }
 
         /**
          * return true if the lastchars buffer does
-         * not contain the lineseparator
+         * not contain the line separator
          */
         private boolean isMissingEndOfLine() {
             for (int i = 0; i < lastChars.length; ++i) {
@@ -383,14 +379,15 @@ public class Concat extends Task implements ResourceCollection {
         private ConcatResource(ResourceCollection c) {
             this.c = c;
         }
-        public InputStream getInputStream() throws IOException {
+        @Override
+        public InputStream getInputStream() {
             if (binary) {
                 ConcatResourceInputStream result = new ConcatResourceInputStream(c);
                 result.setManagingComponent(this);
                 return result;
             }
             Reader resourceReader = getFilteredReader(
-                    new MultiReader<Resource>(c.iterator(), resourceReaderFactory));
+                    new MultiReader<>(c.iterator(), resourceReaderFactory));
             Reader rdr;
             if (header == null && footer == null) {
                 rdr = resourceReader;
@@ -418,12 +415,13 @@ public class Concat extends Task implements ResourceCollection {
                         readers[pos] = getFilteredReader(readers[pos]);
                     }
                 }
-                rdr = new MultiReader<Reader>(Arrays.asList(readers).iterator(),
+                rdr = new MultiReader<>(Arrays.asList(readers).iterator(),
                         identityReaderFactory);
             }
             return outputEncoding == null ? new ReaderInputStream(rdr)
                     : new ReaderInputStream(rdr, outputEncoding);
         }
+        @Override
         public String getName() {
             return resourceName == null
                     ? "concat (" + String.valueOf(c) + ")" : resourceName;
@@ -492,6 +490,7 @@ public class Concat extends Task implements ResourceCollection {
     private String resourceName;
 
     private ReaderFactory<Resource> resourceReaderFactory = new ReaderFactory<Resource>() {
+        @Override
         public Reader getReader(Resource o) throws IOException {
             InputStream is = o.getInputStream();
             return new BufferedReader(encoding == null
@@ -500,11 +499,7 @@ public class Concat extends Task implements ResourceCollection {
         }
     };
 
-    private ReaderFactory<Reader> identityReaderFactory = new ReaderFactory<Reader>() {
-        public Reader getReader(Reader o) {
-            return o;
-        }
-    };
+    private ReaderFactory<Reader> identityReaderFactory = o -> o;
 
     /**
      * Construct a new Concat task.
@@ -529,7 +524,7 @@ public class Concat extends Task implements ResourceCollection {
         binary = false;
         outputWriter = null;
         textBuffer = null;
-        eolString = StringUtils.LINE_SEP;
+        eolString = System.lineSeparator();
         rc = null;
         ignoreEmpty = true;
         force = false;
@@ -594,6 +589,7 @@ public class Concat extends Task implements ResourceCollection {
      * @since Ant 1.6
      * @deprecated use #setOverwrite instead
      */
+    @Deprecated
     public void setForce(boolean forceOverwrite) {
         this.forceOverwrite = forceOverwrite;
     }
@@ -614,6 +610,7 @@ public class Concat extends Task implements ResourceCollection {
      *
      * <p>Defaults to false</p>
      *
+     * @param f boolean
      * @since Ant 1.8.2
      */
     public void setForceReadOnly(boolean f) {
@@ -624,7 +621,7 @@ public class Concat extends Task implements ResourceCollection {
      * Sets the behavior when no source resource files are available. If set to
      * <code>false</code> the destination file will always be created.
      * Defaults to <code>true</code>.
-     * @param ignoreEmpty if false honour destinationfile creation.
+     * @param ignoreEmpty if false, honour destination file creation.
      * @since Ant 1.8.0
      */
     public void setIgnoreEmpty(boolean ignoreEmpty) {
@@ -692,14 +689,14 @@ public class Concat extends Task implements ResourceCollection {
      */
     public void addFilterChain(FilterChain filterChain) {
         if (filterChains == null) {
-            filterChains = new Vector<FilterChain>();
+            filterChains = new Vector<>();
         }
         filterChains.addElement(filterChain);
     }
 
     /**
      * This method adds text which appears in the 'concat' element.
-     * @param text the text to be concated.
+     * @param text the text to be concatenated.
      */
     public void addText(String text) {
         if (textBuffer == null) {
@@ -752,11 +749,11 @@ public class Concat extends Task implements ResourceCollection {
      */
     public void setEol(FixCRLF.CrLf crlf) {
         String s = crlf.getValue();
-        if (s.equals("cr") || s.equals("mac")) {
+        if ("cr".equals(s) || "mac".equals(s)) {
             eolString = "\r";
-        } else if (s.equals("lf") || s.equals("unix")) {
+        } else if ("lf".equals(s) || "unix".equals(s)) {
             eolString = "\n";
-        } else if (s.equals("crlf") || s.equals("dos")) {
+        } else if ("crlf".equals(s) || "dos".equals(s)) {
             eolString = "\r\n";
         }
     }
@@ -785,6 +782,7 @@ public class Concat extends Task implements ResourceCollection {
     /**
      * Execute the concat task.
      */
+    @Override
     public void execute() {
         validate();
         if (binary && dest == null) {
@@ -796,7 +794,7 @@ public class Concat extends Task implements ResourceCollection {
             log(dest + " is up-to-date.", Project.MSG_VERBOSE);
             return;
         }
-        if (c.size() == 0 && ignoreEmpty) {
+        if (c.isEmpty() && ignoreEmpty) {
             return;
         }
         try {
@@ -815,15 +813,19 @@ public class Concat extends Task implements ResourceCollection {
      * Implement ResourceCollection.
      * @return Iterator&lt;Resource&gt;.
      */
+    @Override
     public Iterator<Resource> iterator() {
         validate();
-        return Collections.<Resource>singletonList(new ConcatResource(getResources())).iterator();
+        return Collections
+            .<Resource> singletonList(new ConcatResource(getResources()))
+            .iterator();
     }
 
     /**
      * Implement ResourceCollection.
      * @return 1.
      */
+    @Override
     public int size() {
         return 1;
     }
@@ -832,6 +834,7 @@ public class Concat extends Task implements ResourceCollection {
      * Implement ResourceCollection.
      * @return false.
      */
+    @Override
     public boolean isFilesystemOnly() {
         return false;
     }
@@ -852,8 +855,7 @@ public class Concat extends Task implements ResourceCollection {
             }
             if (encoding != null || outputEncoding != null) {
                 throw new BuildException(
-                    "Setting input or output encoding is incompatible with binary"
-                    + " concatenation");
+                    "Setting input or output encoding is incompatible with binary concatenation");
             }
             if (filterChains != null) {
                 throw new BuildException(
@@ -899,8 +901,9 @@ public class Concat extends Task implements ResourceCollection {
             checkDestNotInSources.add(rc);
             checkDestNotInSources.add(dest);
             if (checkDestNotInSources.size() > 0) {
-                throw new BuildException("Destination resource " + dest
-                        + " was specified as an input resource.");
+                throw new BuildException(
+                    "Destination resource %s was specified as an input resource.",
+                    dest);
             }
         }
         Restrict noexistRc = new Restrict();
@@ -916,15 +919,8 @@ public class Concat extends Task implements ResourceCollection {
     }
 
     private boolean isUpToDate(ResourceCollection c) {
-        if (dest == null || forceOverwrite) {
-            return false;
-        }
-        for (Resource r : c) {
-            if (SelectorUtils.isOutOfDate(r, dest, FILE_UTILS.getFileTimestampGranularity())) {
-                return false;
-            }
-        }
-        return true;
+        return dest != null && !forceOverwrite
+                && c.stream().noneMatch(r -> SelectorUtils.isOutOfDate(r, dest, FILE_UTILS.getFileTimestampGranularity()));
     }
 
     /**
@@ -934,7 +930,7 @@ public class Concat extends Task implements ResourceCollection {
      * for &quot;ignorable whitespace&quot; as well.</p>
      */
     private void sanitizeText() {
-        if (textBuffer != null && "".equals(textBuffer.toString().trim())) {
+        if (textBuffer != null && textBuffer.toString().trim().isEmpty()) {
             textBuffer = null;
         }
     }
