@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -86,10 +86,6 @@ import org.apache.tools.ant.util.JavaEnvUtils;
  * @ant.task category="java"
  */
 public class Javadoc extends Task {
-    // Whether *this VM* is 1.4+ (but also check executable != null).
-
-    private static final boolean JAVADOC_5 =
-        !JavaEnvUtils.isJavaVersion(JavaEnvUtils.JAVA_1_4);
 
     private static final String LOAD_FRAME = "function loadFrames() {";
     private static final int LOAD_FRAME_LEN = LOAD_FRAME.length();
@@ -1850,8 +1846,12 @@ public class Javadoc extends Task {
         doDocFilesSubDirs(toExecute); // docfilessubdir attribute
         doModuleArguments(toExecute);
 
-        doJava14(toExecute);
-        if (breakiterator && (doclet == null || JAVADOC_5)) {
+        doTags(toExecute);
+        doSource(toExecute);
+        doLinkSource(toExecute);
+        doNoqualifier(toExecute);
+		
+        if (breakiterator) {
             toExecute.createArgument().setValue("-breakiterator");
         }
         // If using an external file, write the command line options to it
@@ -1868,7 +1868,7 @@ public class Javadoc extends Task {
              */
             BufferedWriter srcListWriter = null;
             if (useExternalFile) {
-                tmpList = FILE_UTILS.createTempFile("javadoc", "", null, true, true);
+                tmpList = FILE_UTILS.createTempFile(getProject(), "javadoc", "", null, true, true);
                 toExecute.createArgument()
                     .setValue("@" + tmpList.getAbsolutePath());
                 wr = new FileWriter(tmpList.getAbsolutePath(), true);
@@ -2049,7 +2049,7 @@ public class Javadoc extends Task {
         File optionsTmpFile = null;
         try {
             optionsTmpFile = FILE_UTILS.createTempFile(
-                "javadocOptions", "", null, true, true);
+                getProject(), "javadocOptions", "", null, true, true);
             final String[] listOpt = toExecute.getArguments();
             toExecute.clearArgs();
             toExecute.createArgument().setValue(
@@ -2211,8 +2211,28 @@ public class Javadoc extends Task {
         }
     }
 
-    // Do java1.4 arguments
-    private void doJava14(final Commandline toExecute) {
+    private void doNoqualifier(final Commandline toExecute) {
+        if (noqualifier != null && doclet == null) {
+            toExecute.createArgument().setValue("-noqualifier");
+            toExecute.createArgument().setValue(noqualifier);
+        }
+    }
+
+    private void doLinkSource(final Commandline toExecute) {
+        if (linksource && doclet == null) {
+            toExecute.createArgument().setValue("-linksource");
+        }
+    }
+
+    private void doSource(final Commandline toExecute) {
+        final String sourceArg = source != null ? source : getProject().getProperty(MagicNames.BUILD_JAVAC_SOURCE);
+        if (sourceArg != null) {
+            toExecute.createArgument().setValue("-source");
+            toExecute.createArgument().setValue(sourceArg);
+        }
+    }
+
+    private void doTags(final Commandline toExecute) {
         for (final Object element : tags) {
             if (element instanceof TagArgument) {
                 final TagArgument ta = (TagArgument) element;
@@ -2226,53 +2246,33 @@ public class Javadoc extends Task {
                     // The tag element is used as a
                     // fileset. Parse all the files and create
                     // -tag arguments.
-                    final DirectoryScanner tagDefScanner =
-                        ta.getDirectoryScanner(getProject());
+                    final DirectoryScanner tagDefScanner = ta.getDirectoryScanner(getProject());
                     for (String file : tagDefScanner.getIncludedFiles()) {
                         final File tagDefFile = new File(tagDir, file);
-                        try (final BufferedReader in = new BufferedReader(
-                                new FileReader(tagDefFile))) {
+                        try (final BufferedReader in = new BufferedReader(new FileReader(tagDefFile))) {
                             in.lines().forEach(line -> {
                                 toExecute.createArgument().setValue("-tag");
                                 toExecute.createArgument().setValue(line);
                             });
                         } catch (final IOException ioe) {
-                            throw new BuildException("Couldn't read tag file from "
-                                    + tagDefFile.getAbsolutePath(), ioe);
+                            throw new BuildException("Couldn't read tag file from " + tagDefFile.getAbsolutePath(),
+                                    ioe);
                         }
                     }
                 }
             } else {
                 final ExtensionInfo tagletInfo = (ExtensionInfo) element;
                 toExecute.createArgument().setValue("-taglet");
-                toExecute.createArgument().setValue(tagletInfo
-                                                    .getName());
+                toExecute.createArgument().setValue(tagletInfo.getName());
                 if (tagletInfo.getPath() != null) {
-                    final Path tagletPath = tagletInfo.getPath()
-                        .concatSystemClasspath("ignore");
+                    final Path tagletPath = tagletInfo.getPath().concatSystemClasspath("ignore");
                     if (!tagletPath.isEmpty()) {
-                        toExecute.createArgument()
-                            .setValue("-tagletpath");
+                        toExecute.createArgument().setValue("-tagletpath");
                         toExecute.createArgument().setPath(tagletPath);
                     }
                 }
             }
         }
-
-        final String sourceArg = source != null ? source
-            : getProject().getProperty(MagicNames.BUILD_JAVAC_SOURCE);
-        if (sourceArg != null) {
-            toExecute.createArgument().setValue("-source");
-            toExecute.createArgument().setValue(sourceArg);
-        }
-
-        if (linksource && doclet == null) {
-            toExecute.createArgument().setValue("-linksource");
-        }
-        if (noqualifier != null && doclet == null) {
-            toExecute.createArgument().setValue("-noqualifier");
-            toExecute.createArgument().setValue(noqualifier);
-        }
     }
 
     private void doDocFilesSubDirs(final Commandline toExecute) {
@@ -2499,7 +2499,7 @@ public class Javadoc extends Task {
                 // Path.list does it for us.
                 sp.createPathElement().setLocation(baseDir);
             } else {
-                log(baseDir + " doesn\'t contain any packages, dropping it.",
+                log(baseDir + " doesn't contain any packages, dropping it.",
                     Project.MSG_VERBOSE);
             }
         }
