@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -72,13 +72,11 @@ public class KeySubst extends Task {
             String newline = null;
             line = br.readLine();
             while (line != null) {
-                if (line.isEmpty()) {
-                    bw.newLine();
-                } else {
+                if (!line.isEmpty()) {
                     newline = KeySubst.replace(line, replacements);
                     bw.write(newline);
-                    bw.newLine();
                 }
+                bw.newLine();
                 line = br.readLine();
             }
             bw.flush();
