@@ -48,6 +48,7 @@ import java.util.stream.Stream;
 
 import org.apache.tools.ant.AntClassLoader;
 import org.apache.tools.ant.BuildException;
+import org.apache.tools.ant.MagicNames;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.Task;
 import org.apache.tools.ant.taskdefs.Execute;
@@ -1427,7 +1428,7 @@ public class JUnitTask extends Task {
      * @return created file
      */
     private File createTempPropertiesFile(final String prefix) {
-        return FILE_UTILS.createTempFile(prefix, ".properties",
+        return FILE_UTILS.createTempFile(getProject(), prefix, ".properties",
             tmpDir != null ? tmpDir : getProject().getBaseDir(), true, true);
     }
 
@@ -1838,7 +1839,7 @@ public class JUnitTask extends Task {
             antRuntimeClasses.createPath().setLocation(f);
             return true;
         } else {
-            log("Couldn\'t find " + resource, Project.MSG_DEBUG);
+            log("Couldn't find " + resource, Project.MSG_DEBUG);
             return false;
         }
     }
@@ -1972,7 +1973,7 @@ public class JUnitTask extends Task {
                 // make sure the test annotation are accepted
                 classLoader.addSystemPackageRoot("org.junit");
                 // will cause trouble in JDK 1.1 if omitted
-                classLoader.addSystemPackageRoot("org.apache.tools.ant");
+                classLoader.addSystemPackageRoot(MagicNames.ANT_CORE_PACKAGE);
             }
         }
     }
