@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -24,7 +24,6 @@ import java.util.Enumeration;
 import java.util.List;
 import java.util.Stack;
 import java.util.stream.Collectors;
-import java.util.stream.Stream;
 
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.DirectoryScanner;
@@ -37,8 +36,8 @@ import org.apache.tools.ant.types.selectors.DateSelector;
 import org.apache.tools.ant.types.selectors.DependSelector;
 import org.apache.tools.ant.types.selectors.DepthSelector;
 import org.apache.tools.ant.types.selectors.DifferentSelector;
-import org.apache.tools.ant.types.selectors.ExtendSelector;
 import org.apache.tools.ant.types.selectors.ExecutableSelector;
+import org.apache.tools.ant.types.selectors.ExtendSelector;
 import org.apache.tools.ant.types.selectors.FileSelector;
 import org.apache.tools.ant.types.selectors.FilenameSelector;
 import org.apache.tools.ant.types.selectors.MajoritySelector;
@@ -46,6 +45,8 @@ import org.apache.tools.ant.types.selectors.NoneSelector;
 import org.apache.tools.ant.types.selectors.NotSelector;
 import org.apache.tools.ant.types.selectors.OrSelector;
 import org.apache.tools.ant.types.selectors.OwnedBySelector;
+import org.apache.tools.ant.types.selectors.PosixGroupSelector;
+import org.apache.tools.ant.types.selectors.PosixPermissionsSelector;
 import org.apache.tools.ant.types.selectors.PresentSelector;
 import org.apache.tools.ant.types.selectors.ReadableSelector;
 import org.apache.tools.ant.types.selectors.SelectSelector;
@@ -195,7 +196,7 @@ public abstract class AbstractFileSet extends DataType
 
     /**
      * Add a name entry to the include files list.
-     * @return <code>PatternSet.NameEntry</code>.
+     * @return <code>PatternSet.PatternFileNameEntry</code>.
      */
     public synchronized PatternSet.NameEntry createIncludesFile() {
         if (isReference()) {
@@ -219,7 +220,7 @@ public abstract class AbstractFileSet extends DataType
 
     /**
      * Add a name entry to the excludes files list.
-     * @return <code>PatternSet.NameEntry</code>.
+     * @return <code>PatternSet.PatternFileNameEntry</code>.
      */
     public synchronized PatternSet.NameEntry createExcludesFile() {
         if (isReference()) {
@@ -283,8 +284,8 @@ public abstract class AbstractFileSet extends DataType
             throw tooManyAttributes();
         }
         if (includes != null) {
-            for (int i = 0; i < includes.length; i++) {
-                defaultPatterns.createInclude().setName(includes[i]);
+            for (String include : includes) {
+                defaultPatterns.createInclude().setName(include);
             }
             directoryScanner = null;
         }
@@ -318,8 +319,8 @@ public abstract class AbstractFileSet extends DataType
             throw tooManyAttributes();
         }
         if (excludes != null) {
-            for (int i = 0; i < excludes.length; i++) {
-                defaultPatterns.createExclude().setName(excludes[i]);
+            for (String exclude : excludes) {
+                defaultPatterns.createExclude().setName(exclude);
             }
             directoryScanner = null;
         }
@@ -572,11 +573,16 @@ public abstract class AbstractFileSet extends DataType
     /**
      * Performs the check for circular references and returns the
      * referenced FileSet.
+     * This method can be overridden together with {@link ArchiveFileSet#getRef() getRef()}
+     * providing implementations containing the special support
+     * for FileSet references, which can be handled by all ArchiveFileSets.
+     * NB! This method must be overridden in subclasses such as FileSet and DirSet
+     * to distinguish between the data types.
      * @param p the current project
-     * @return the referenced FileSet
+     * @return the dereferenced object.
      */
     protected AbstractFileSet getRef(Project p) {
-        return (AbstractFileSet) getCheckedRef(p);
+        return getCheckedRef(AbstractFileSet.class, getDataTypeName(), p);
     }
 
     // SelectorContainer methods
@@ -592,7 +598,7 @@ public abstract class AbstractFileSet extends DataType
             return getRef(getProject()).hasSelectors();
         }
         dieOnCircularReference();
-        return !(selectors.isEmpty());
+        return !selectors.isEmpty();
     }
 
     /**
@@ -605,10 +611,8 @@ public abstract class AbstractFileSet extends DataType
             return getRef(getProject()).hasPatterns();
         }
         dieOnCircularReference();
-        if (defaultPatterns.hasPatterns(getProject())) {
-            return true;
-        }
-        return additionalPatterns.stream().anyMatch(ps -> ps.hasPatterns(getProject()));
+        return defaultPatterns.hasPatterns(getProject())
+                || additionalPatterns.stream().anyMatch(ps -> ps.hasPatterns(getProject()));
     }
 
     /**
@@ -826,7 +830,7 @@ public abstract class AbstractFileSet extends DataType
     /**
      * Add the modified selector.
      * @param selector the <code>ModifiedSelector</code> to add.
-     * @since ant 1.6
+     * @since Ant 1.6
      */
     @Override
     public void addModified(ModifiedSelector selector) {
@@ -865,6 +869,22 @@ public abstract class AbstractFileSet extends DataType
         appendSelector(o);
     }
 
+    /**
+     * @param o PosixGroupSelector
+     * @since 1.10.4
+     */
+    public void addPosixGroup(PosixGroupSelector o) {
+        appendSelector(o);
+    }
+
+    /**
+     * @param o PosixPermissionsSelector
+     * @since 1.10.4
+     */
+    public void addPosixPermissions(PosixPermissionsSelector o) {
+        appendSelector(o);
+    }
+
     /**
      * Add an arbitrary selector.
      * @param selector the <code>FileSelector</code> to add.
@@ -886,8 +906,7 @@ public abstract class AbstractFileSet extends DataType
             return getRef(getProject()).toString();
         }
         dieOnCircularReference();
-        DirectoryScanner ds = getDirectoryScanner(getProject());
-        return Stream.of(ds.getIncludedFiles()).collect(Collectors.joining(";"));
+        return String.join(";", getDirectoryScanner().getIncludedFiles());
     }
 
     /**
@@ -905,8 +924,8 @@ public abstract class AbstractFileSet extends DataType
         try {
             AbstractFileSet fs = (AbstractFileSet) super.clone();
             fs.defaultPatterns = (PatternSet) defaultPatterns.clone();
-            fs.additionalPatterns = additionalPatterns.stream().map(
-                    PatternSet::clone).map(PatternSet.class::cast).collect(Collectors.toList());
+            fs.additionalPatterns = additionalPatterns.stream().map(PatternSet::clone)
+                    .map(PatternSet.class::cast).collect(Collectors.toList());
             fs.selectors = new ArrayList<>(selectors);
             return fs;
         } catch (CloneNotSupportedException e) {
@@ -965,12 +984,9 @@ public abstract class AbstractFileSet extends DataType
         if (isReference()) {
             super.dieOnCircularReference(stk, p);
         } else {
-            selectors.stream().filter(DataType.class::isInstance).forEach(fileSelector ->
-                pushAndInvokeCircularReferenceCheck((DataType) fileSelector, stk, p)
-            );
-            for (PatternSet ps : additionalPatterns) {
-                pushAndInvokeCircularReferenceCheck(ps, stk, p);
-            }
+            selectors.stream().filter(DataType.class::isInstance).map(DataType.class::cast)
+                    .forEach(type -> pushAndInvokeCircularReferenceCheck(type, stk, p));
+            additionalPatterns.forEach(ps -> pushAndInvokeCircularReferenceCheck(ps, stk, p));
             setChecked(true);
         }
     }
