@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -34,7 +34,6 @@ import org.apache.tools.ant.Project;
 import org.apache.tools.ant.types.DataType;
 import org.apache.tools.ant.types.Resource;
 import org.apache.tools.ant.types.ResourceCollection;
-import org.apache.tools.ant.util.CollectionUtils;
 
 /**
  * Generic ResourceCollection: Either stores nested ResourceCollections,
@@ -90,7 +89,8 @@ public class Resources extends DataType implements ResourceCollection {
         private synchronized Collection<Resource> getCache() {
             Collection<Resource> coll = cached;
             if (coll == null) {
-                coll = CollectionUtils.asCollection(new MyIterator());
+                coll = new ArrayList<>();
+                new MyIterator().forEachRemaining(coll::add);
                 if (cache) {
                     cached = coll;
                 }
@@ -219,7 +219,7 @@ public class Resources extends DataType implements ResourceCollection {
     @Override
     public synchronized String toString() {
         if (isReference()) {
-            return getCheckedRef().toString();
+            return getRef().toString();
         }
         validate();
         if (coll == null || coll.isEmpty()) {
@@ -266,7 +266,7 @@ public class Resources extends DataType implements ResourceCollection {
      * @return the referenced ResourceCollection.
      */
     private ResourceCollection getRef() {
-        return getCheckedRef(ResourceCollection.class, "ResourceCollection");
+        return getCheckedRef(ResourceCollection.class);
     }
 
     private synchronized void validate() {
@@ -275,6 +275,6 @@ public class Resources extends DataType implements ResourceCollection {
     }
 
     private synchronized List<ResourceCollection> getNested() {
-        return rc == null ? Collections.<ResourceCollection> emptyList() : rc;
+        return rc == null ? Collections.emptyList() : rc;
     }
 }
