@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -125,17 +125,17 @@ public class FilenameSelector extends BaseExtendSelector {
     public void setParameters(Parameter... parameters) {
         super.setParameters(parameters);
         if (parameters != null) {
-            for (int i = 0; i < parameters.length; i++) {
-                String paramname = parameters[i].getName();
+            for (Parameter parameter : parameters) {
+                String paramname = parameter.getName();
                 if (NAME_KEY.equalsIgnoreCase(paramname)) {
-                    setName(parameters[i].getValue());
+                    setName(parameter.getValue());
                 } else if (CASE_KEY.equalsIgnoreCase(paramname)) {
                     setCasesensitive(Project.toBoolean(
-                            parameters[i].getValue()));
+                            parameter.getValue()));
                 } else if (NEGATE_KEY.equalsIgnoreCase(paramname)) {
-                    setNegate(Project.toBoolean(parameters[i].getValue()));
+                    setNegate(Project.toBoolean(parameter.getValue()));
                 } else if (REGEX_KEY.equalsIgnoreCase(paramname)) {
-                    setRegex(parameters[i].getValue());
+                    setRegex(parameter.getValue());
                 } else {
                     setError("Invalid parameter " + paramname);
                 }
