@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,6 +23,7 @@ import java.io.OutputStream;
 import java.io.OutputStreamWriter;
 import java.io.StringWriter;
 import java.io.Writer;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
@@ -151,8 +152,6 @@ public class DOMElementWriter {
         this.namespacePolicy = namespacePolicy;
     }
 
-    private static String lSep = System.getProperty("line.separator");
-
     // CheckStyle:VisibilityModifier OFF - bc
     /**
      * Don't try to be too smart but at least recognize the predefined
@@ -172,7 +171,7 @@ public class DOMElementWriter {
      * @throws IOException if an error happens while writing to the stream.
      */
     public void write(Element root, OutputStream out) throws IOException {
-        Writer wri = new OutputStreamWriter(out, "UTF8");
+        Writer wri = new OutputStreamWriter(out, StandardCharsets.UTF_8);
         writeXMLDeclaration(wri);
         write(root, wri, 0, "  ");
         wri.flush();
@@ -219,7 +218,7 @@ public class DOMElementWriter {
                 case Node.ELEMENT_NODE:
                     hasChildElements = true;
                     if (i == 0) {
-                        out.write(lSep);
+                        out.write(System.lineSeparator());
                     }
                     write((Element) child, out, indent + 1, indentWith);
                     break;
@@ -250,7 +249,7 @@ public class DOMElementWriter {
                     out.write("<?");
                     out.write(child.getNodeName());
                     String data = child.getNodeValue();
-                    if (data != null && data.length() > 0) {
+                    if (data != null && !data.isEmpty()) {
                         out.write(' ');
                         out.write(data);
                     }
@@ -306,7 +305,7 @@ public class DOMElementWriter {
         out.write("<");
         if (namespacePolicy.qualifyElements) {
             String uri = getNamespaceURI(element);
-            String prefix = (String) nsPrefixMap.get(uri);
+            String prefix = nsPrefixMap.get(uri);
             if (prefix == null) {
                 if (nsPrefixMap.isEmpty()) {
                     // steal default namespace
@@ -317,7 +316,7 @@ public class DOMElementWriter {
                 nsPrefixMap.put(uri, prefix);
                 addNSDefinition(element, uri);
             }
-            if (!"".equals(prefix)) {
+            if (!prefix.isEmpty()) {
                 out.write(prefix);
                 out.write(":");
             }
@@ -331,7 +330,7 @@ public class DOMElementWriter {
             out.write(" ");
             if (namespacePolicy.qualifyAttributes) {
                 String uri = getNamespaceURI(attr);
-                String prefix = (String) nsPrefixMap.get(uri);
+                String prefix = nsPrefixMap.get(uri);
                 if (prefix == null) {
                     prefix = NS + (nextPrefix++);
                     nsPrefixMap.put(uri, prefix);
@@ -352,7 +351,7 @@ public class DOMElementWriter {
             for (String uri : uris) {
                 String prefix = nsPrefixMap.get(uri);
                 out.write(" xmlns");
-                if (!"".equals(prefix)) {
+                if (!prefix.isEmpty()) {
                     out.write(":");
                     out.write(prefix);
                 }
@@ -366,8 +365,7 @@ public class DOMElementWriter {
             out.write(">");
         } else {
             removeNSDefinitions(element);
-            out.write(" />");
-            out.write(lSep);
+            out.write(String.format(" />%n"));
             out.flush();
         }
     }
@@ -399,16 +397,15 @@ public class DOMElementWriter {
         out.write("</");
         if (namespacePolicy.qualifyElements) {
             String uri = getNamespaceURI(element);
-            String prefix = (String) nsPrefixMap.get(uri);
-            if (prefix != null && !"".equals(prefix)) {
+            String prefix = nsPrefixMap.get(uri);
+            if (prefix != null && !prefix.isEmpty()) {
                 out.write(prefix);
                 out.write(":");
             }
             removeNSDefinitions(element);
         }
         out.write(element.getTagName());
-        out.write(">");
-        out.write(lSep);
+        out.write(String.format(">%n"));
         out.flush();
     }
 
@@ -434,10 +431,8 @@ public class DOMElementWriter {
     }
 
     private String encode(final String value, final boolean encodeWhitespace) {
-        final int len = value.length();
-        final StringBuilder sb = new StringBuilder(len);
-        for (int i = 0; i < len; i++) {
-            final char c = value.charAt(i);
+        final StringBuilder sb = new StringBuilder(value.length());
+        for (final char c : value.toCharArray()) {
             switch (c) {
             case '<':
                 sb.append("&lt;");
@@ -481,10 +476,10 @@ public class DOMElementWriter {
      * <code>&amp;#x5d;&amp;#x5d;&amp;gt;</code>.</p>
      *
      * <p>See XML 1.0 2.2 <a
-     * href="http://www.w3.org/TR/1998/REC-xml-19980210#charsets">
-     * http://www.w3.org/TR/1998/REC-xml-19980210#charsets</a> and
+     * href="https://www.w3.org/TR/1998/REC-xml-19980210#charsets">
+     * https://www.w3.org/TR/1998/REC-xml-19980210#charsets</a> and
      * 2.7 <a
-     * href="http://www.w3.org/TR/1998/REC-xml-19980210#sec-cdata-sect">http://www.w3.org/TR/1998/REC-xml-19980210#sec-cdata-sect</a>.</p>
+     * href="https://www.w3.org/TR/1998/REC-xml-19980210#sec-cdata-sect">https://www.w3.org/TR/1998/REC-xml-19980210#sec-cdata-sect</a>.</p>
      * @param value the value to be encoded.
      * @return the encoded value.
      */
@@ -507,10 +502,10 @@ public class DOMElementWriter {
      * <code>&amp;#x5d;&amp;#x5d;&amp;gt;</code>.</p>
      *
      * <p>See XML 1.0 2.2 <a
-     * href="http://www.w3.org/TR/1998/REC-xml-19980210#charsets">
-     * http://www.w3.org/TR/1998/REC-xml-19980210#charsets</a> and
+     * href="https://www.w3.org/TR/1998/REC-xml-19980210#charsets">
+     * https://www.w3.org/TR/1998/REC-xml-19980210#charsets</a> and
      * 2.7 <a
-     * href="http://www.w3.org/TR/1998/REC-xml-19980210#sec-cdata-sect">http://www.w3.org/TR/1998/REC-xml-19980210#sec-cdata-sect</a>.</p>
+     * href="https://www.w3.org/TR/1998/REC-xml-19980210#sec-cdata-sect">https://www.w3.org/TR/1998/REC-xml-19980210#sec-cdata-sect</a>.</p>
      * @param value the value to be encoded.
      * @param out where to write the encoded data to.
      * @throws IOException if data cannot be written
@@ -522,13 +517,12 @@ public class DOMElementWriter {
         while (prevEnd < len) {
             final int end = (cdataEndPos < 0 ? len : cdataEndPos);
             // Write out stretches of legal characters in the range [prevEnd, end).
-            for (int prevLegalCharPos = prevEnd; prevLegalCharPos < end;/*empty*/) {
-                int illegalCharPos;
-                for (illegalCharPos = prevLegalCharPos; true; ++illegalCharPos) {
-                    if (illegalCharPos >= end
-                        || !isLegalCharacter(value.charAt(illegalCharPos))) {
-                        break;
-                    }
+            int prevLegalCharPos = prevEnd;
+            while (prevLegalCharPos < end) {
+                int illegalCharPos = prevLegalCharPos;
+                while (illegalCharPos < end
+                        && isLegalCharacter(value.charAt(illegalCharPos))) {
+                    ++illegalCharPos;
                 }
                 out.write(value, prevLegalCharPos, illegalCharPos - prevLegalCharPos);
                 prevLegalCharPos = illegalCharPos + 1;
@@ -550,7 +544,7 @@ public class DOMElementWriter {
      * @return true if it is an entity.
      */
     public boolean isReference(String ent) {
-        if (!(ent.charAt(0) == '&') || !ent.endsWith(";")) {
+        if (ent.charAt(0) != '&' || !ent.endsWith(";")) {
             return false;
         }
 
@@ -575,8 +569,8 @@ public class DOMElementWriter {
         }
 
         String name = ent.substring(1, ent.length() - 1);
-        for (int i = 0; i < knownEntities.length; i++) {
-            if (name.equals(knownEntities[i])) {
+        for (String knownEntity : knownEntities) {
+            if (name.equals(knownEntity)) {
                 return true;
             }
         }
@@ -587,8 +581,8 @@ public class DOMElementWriter {
      * Is the given character allowed inside an XML document?
      *
      * <p>See XML 1.0 2.2 <a
-     * href="http://www.w3.org/TR/1998/REC-xml-19980210#charsets">
-     * http://www.w3.org/TR/1998/REC-xml-19980210#charsets</a>.</p>
+     * href="https://www.w3.org/TR/1998/REC-xml-19980210#charsets">
+     * https://www.w3.org/TR/1998/REC-xml-19980210#charsets</a>.</p>
      * @param c the character to test.
      * @return true if the character is allowed.
      * @since 1.10, Ant 1.5
@@ -607,11 +601,8 @@ public class DOMElementWriter {
         if (c < 0xE000) {
             return false;
         }
-        if (c <= 0xFFFD) {
-            return true;
-        }
+        return c <= 0xFFFD;
         // CheckStyle:MagicNumber ON
-        return false;
     }
 
     private void removeNSDefinitions(Element element) {
