@@ -1,9 +1,27 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *      https://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ */
 package org.apache.tools.ant.taskdefs;
 
 import org.apache.tools.ant.BuildFileRule;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
 
 import java.io.ByteArrayOutputStream;
 import java.io.File;
@@ -23,10 +41,15 @@ public class ExecStreamRedirectorTest {
     @Rule
     public BuildFileRule buildRule = new BuildFileRule();
 
+    @Rule
+    public TemporaryFolder folder = new TemporaryFolder();
+
+    private File outputDir;
+
     @Before
-    public void setUp() {
+    public void setUp() throws IOException {
         buildRule.configureProject("src/etc/testcases/taskdefs/exec/exec-with-redirector.xml");
-        final File outputDir = this.createTmpDir();
+        outputDir = folder.newFolder(String.valueOf("temp-" + System.nanoTime()));
         buildRule.getProject().setUserProperty("output", outputDir.toString());
         buildRule.executeTarget("setUp");
     }
@@ -47,10 +70,9 @@ public class ExecStreamRedirectorTest {
         buildRule.executeTarget("list-dir");
 
         // verify the redirected output
-        final String outputDirPath = buildRule.getProject().getProperty("output");
         byte[] dirListingOutput = null;
         for (int i = 1; i <= 16; i++) {
-            final File redirectedOutputFile = new File(outputDirPath, "ls" + i + ".txt");
+            final File redirectedOutputFile = new File(outputDir, "ls" + i + ".txt");
             assertTrue(redirectedOutputFile + " is missing or not a regular file",
                     redirectedOutputFile.isFile());
             final byte[] redirectedOutput = readAllBytes(redirectedOutputFile);
@@ -68,14 +90,6 @@ public class ExecStreamRedirectorTest {
         }
     }
 
-    private File createTmpDir() {
-        final File tmpDir = new File(System.getProperty("java.io.tmpdir"),
-                String.valueOf("temp-" + System.nanoTime()));
-        tmpDir.mkdir();
-        tmpDir.deleteOnExit();
-        return tmpDir;
-    }
-
     private static byte[] readAllBytes(final File file) throws IOException {
         final ByteArrayOutputStream bos = new ByteArrayOutputStream();
         try (FileInputStream fis = new FileInputStream(file)) {
