@@ -253,6 +253,7 @@ public class JarTest {
             ZipEntry ze = archive.getEntry("META-INF/INDEX.LIST");
             InputStream is = archive.getInputStream(ze);
             BufferedReader r = new BufferedReader(new InputStreamReader(is, StandardCharsets.UTF_8));
+            boolean foundArchive = false;
             boolean foundSub = false;
             boolean foundSubFoo = false;
             boolean foundFoo = false;
@@ -260,6 +261,9 @@ public class JarTest {
             String line = r.readLine();
             while (line != null) {
                 switch (line) {
+                    case "tmp.jar":
+                        foundArchive = true;
+                        break;
                     case "foo":
                         foundFoo = true;
                         break;
@@ -273,6 +277,7 @@ public class JarTest {
                 line = r.readLine();
             }
 
+            assertTrue(foundArchive);
             assertTrue(foundSub);
             assertFalse(foundSubFoo);
             assertTrue(foundFoo);
@@ -287,8 +292,126 @@ public class JarTest {
     }
 
     @Test
-    public void testIndexJarsPlusJarMarker() {
+    public void testIndexJarsPlusJarMarker() throws IOException {
         buildRule.executeTarget("testIndexJarsPlusJarMarker");
+        try (ZipFile archive = new ZipFile(new File(getOutputDir(), tempJar + "2"))) {
+            ZipEntry ze = archive.getEntry("META-INF/INDEX.LIST");
+            InputStream is = archive.getInputStream(ze);
+            BufferedReader r = new BufferedReader(new InputStreamReader(is, StandardCharsets.UTF_8));
+            // tmp.jar
+            boolean foundTmp = false;
+            boolean foundA = false;
+            boolean foundAB = false;
+            boolean foundABC = false;
+
+            // tmp2.jar
+            boolean foundTmp2 = false;
+            boolean foundD = false;
+            boolean foundDE = false;
+            boolean foundDEF = false;
+
+            String line = r.readLine();
+            while (line != null) {
+                switch (line) {
+                    case "tmp.jar":
+                        foundTmp = true;
+                        break;
+                    case "a":
+                        foundA = true;
+                        break;
+                    case "a/b":
+                        foundAB = true;
+                        break;
+                    case "a/b/c":
+                        foundABC = true;
+                        break;
+                    case "tmp.jar2":
+                        foundTmp2 = true;
+                        break;
+                    case "d":
+                        foundD = true;
+                        break;
+                    case "d/e":
+                        foundDE = true;
+                        break;
+                    case "d/e/f":
+                        foundDEF = true;
+                        break;
+                }
+                line = r.readLine();
+            }
+
+            assertTrue(foundTmp);
+            assertTrue(foundA);
+            assertTrue(foundAB);
+            assertTrue(foundABC);
+            assertTrue(foundTmp2);
+            assertTrue(foundD);
+            assertTrue(foundDE);
+            assertTrue(foundDEF);
+        }
+    }
+
+    @Test
+    public void testIndexJarsPlusJarMarkerWithMapping() throws IOException {
+        buildRule.executeTarget("testIndexJarsPlusJarMarkerWithMapping");
+        try (ZipFile archive = new ZipFile(new File(getOutputDir(), tempJar + "2"))) {
+            ZipEntry ze = archive.getEntry("META-INF/INDEX.LIST");
+            InputStream is = archive.getInputStream(ze);
+            BufferedReader r = new BufferedReader(new InputStreamReader(is, StandardCharsets.UTF_8));
+            // tmp.jar
+            boolean foundTmp = false;
+            boolean foundA = false;
+            boolean foundAB = false;
+            boolean foundABC = false;
+
+            // tmp2.jar
+            boolean foundTmp2 = false;
+            boolean foundD = false;
+            boolean foundDE = false;
+            boolean foundDEF = false;
+
+            String line = r.readLine();
+            while (line != null) {
+                System.out.println("line = " + line);
+                switch (line) {
+                    case "foo/tmp.jar":
+                        foundTmp = true;
+                        break;
+                    case "a":
+                        foundA = true;
+                        break;
+                    case "a/b":
+                        foundAB = true;
+                        break;
+                    case "a/b/c":
+                        foundABC = true;
+                        break;
+                    case "tmp.jar2":
+                        foundTmp2 = true;
+                        break;
+                    case "d":
+                        foundD = true;
+                        break;
+                    case "d/e":
+                        foundDE = true;
+                        break;
+                    case "d/e/f":
+                        foundDEF = true;
+                        break;
+                }
+                line = r.readLine();
+            }
+
+            assertTrue(foundTmp);
+            assertTrue(foundA);
+            assertTrue(foundAB);
+            assertTrue(foundABC);
+            assertTrue(foundTmp2);
+            assertTrue(foundD);
+            assertTrue(foundDE);
+            assertTrue(foundDEF);
+        }
     }
 
     @Test
