@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,8 @@
 
 package org.apache.tools.tar;
 
+import java.io.File;
+
 import org.junit.Test;
 
 /**
@@ -30,6 +32,6 @@ public class TarEntryTest {
      */
     @Test
     public void testFileConstructor() {
-        new TarEntry(new java.io.File("/foo"));
+        new TarEntry(new File("/foo"));
     }
 }
